<template>
  <div class="not-found-container">
    <div class="not-found-card-wrapper">
      <div class="not-found-card">
        <!-- Header Section -->
        <div class="card-header">
          <div class="header-icon">
            <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" 
                d="M9.172 16.172a4 4 0 015.656 0M9 10h.01M15 10h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
            </svg>
          </div>
          <h2>404 Error</h2>
          <p>Page Not Found</p>
        </div>

        <!-- Content Section -->
        <div class="card-content">
          <div class="error-illustration">
            <svg class="error-icon" viewBox="0 0 24 24" fill="none" stroke="currentColor">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" 
                d="M3 12l2-2m0 0l7-7 7 7M5 10v10a1 1 0 001 1h3m10-11l2 2m-2-2v10a1 1 0 01-1 1h-3m-6 0a1 1 0 001-1v-4a1 1 0 011-1h2a1 1 0 011 1v4a1 1 0 001 1m-6 0h6" />
            </svg>
          </div>
          <h3 class="error-heading">Oops! Page not found</h3>
          <p class="error-message">The page you're looking for doesn't exist or has been moved.</p>
          
          <router-link to="/dashboard" class="button primary">
            Back to Home
          </router-link>
        </div>
      </div>

      <!-- Footer -->
      <p class="footer-text">
        Need help? 
        <a href="#" class="support-link">Contact our support team</a>
      </p>
    </div>
  </div>
</template>

<script>
export default {
  name: "NotFound",
};
</script>

<style scoped>
.not-found-container {
  min-height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 1rem;
  background: linear-gradient(135deg, #f0f4ff 0%, #eef1ff 100%);
}

.not-found-card-wrapper {
  width: 100%;
  max-width: 440px;
}

.not-found-card {
  background: white;
  border-radius: 1rem;
  overflow: hidden;
  box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
}

.card-header {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  padding: 2rem 1.5rem;
  text-align: center;
  color: white;
}

.header-icon {
  width: 4rem;
  height: 4rem;
  margin: 0 auto 1rem;
  background: rgba(255, 255, 255, 0.1);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  backdrop-filter: blur(4px);
}

.card-header h2 {
  font-size: 1.5rem;
  font-weight: 700;
  margin: 0 0 0.5rem;
}

.card-header p {
  color: rgba(255, 255, 255, 0.9);
  margin: 0;
}

.card-content {
  padding: 2rem 1.5rem;
  text-align: center;
}

.error-illustration {
  width: 8rem;
  height: 8rem;
  margin: 0 auto 1.5rem;
  color: #6b7280;
}

.error-icon {
  width: 100%;
  height: 100%;
}

.error-heading {
  font-size: 1.25rem;
  font-weight: 600;
  color: #111827;
  margin: 0 0 0.5rem;
}

.error-message {
  color: #6b7280;
  margin-bottom: 2rem;
  font-size: 1rem;
  line-height: 1.5;
}

.button {
  display: inline-flex;
  padding: 0.875rem 1.5rem;
  border-radius: 0.5rem;
  font-weight: 500;
  justify-content: center;
  align-items: center;
  transition: all 0.2s;
  cursor: pointer;
  border: none;
  font-size: 1rem;
  text-decoration: none;
}

.button.primary {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  color: white;
  box-shadow: 0 4px 12px rgba(59, 130, 246, 0.25);
}

.button.primary:hover {
  background: linear-gradient(to right, #2563eb, #4338ca);
  transform: translateY(-1px);
}

.footer-text {
  text-align: center;
  color: #4b5563;
  font-size: 0.875rem;
  margin-top: 1rem;
}

.support-link {
  color: #3b82f6;
  text-decoration: none;
  font-weight: 500;
}

.support-link:hover {
  color: #2563eb;
}

.icon {
  width: 1.5rem;
  height: 1.5rem;
}

/* Responsive adjustments */
@media (max-width: 640px) {
  .not-found-container {
    padding: 1rem;
  }
  
  .card-header {
    padding: 1.5rem 1rem;
  }
  
  .card-content {
    padding: 1.5rem 1rem;
  }

  .error-illustration {
    width: 6rem;
    height: 6rem;
  }
}
</style>